@@ -3,10 +3,6 @@
 set -e
 
 # Read debian specific configuration
-. /etc/gitlab-common/gitlab-common.conf
-. /etc/gitlab/gitlab-debian.conf
-export DB RAILS_ENV
-
-cd /usr/share/gitlab
+. /usr/lib/gitlab/scripts/gitlab-env.sh
 
 runuser -u ${gitlab_user} -- sh -c "/usr/bin/bundle exec rails console -e production"
