@@ -51,6 +51,7 @@ if [ "$db_relations" = "No relations found." ] || \
   runuser -u ${gitlab_user} -- sh -c \
   "touch ${gitlab_data_dir}/.gitlab_shell_secret"
   runuser -u ${gitlab_user} -- sh -c '/usr/bin/bundle exec rake db:schema:load'
+  runuser -u ${gitlab_user} -- sh -c '/usr/bin/bundle exec rake db:seed_fu'
 else
   echo "gitlab_production database is not empty, skipping gitlab setup"
 fi
@@ -78,7 +79,7 @@ runuser -u ${gitlab_user} -- sh -c 'yarnpkg set version classic'
 
 # This is added by yarnpkg command above and will make command below to fail
 runuser -u ${gitlab_user} -- sh -c "sed -i '/.*\"packageManager\".*/d' /var/lib/gitlab/package.json"
-runuser -u ${gitlab_user} -- sh -c "sed -i '/,\n\}/d' /var/lib/gitlab/package.json"
+runuser -u ${gitlab_user} -- sh -c "json5 -s 2 /var/lib/gitlab/package.json -o /var/lib/gitlab/package.json"
 
 echo "Installing node modules..."
 runuser -u ${gitlab_user} -- sh -c 'yarnpkg --frozen-lockfile install'
