@@ -1,4 +1,4 @@
-  LC_ALL=C.UTF-8 ls -1a |grep -vx .git |grep -vx .pc > debian/upstream-file-list.new
+LC_ALL=C.UTF-8 ls -1a |grep -vx .git |grep -vx .pc |grep -vx _build |grep -vx \*.rej > debian/upstream-file-list.new
 if ! diff -u debian/upstream-file-list debian/upstream-file-list.new
 then
   echo "Upstream added or removed files"
